@@ -1,13 +1,13 @@
 from typing import List
 
-from mercapi.models.base import Extractors, ResponseModel
+from mercapi.models.base import Extractors, ResponseModel, ResponseProperty
 from mercapi.models.search import SearchResultItem, Meta
 
 
 class SearchResults(ResponseModel):
     _required_properties = [
-        ("meta", "meta", Extractors.get_as_model("meta", Meta)),
-        (
+        ResponseProperty("meta", "meta", Extractors.get_as_model("meta", Meta)),
+        ResponseProperty(
             "items",
             "items",
             Extractors.get_list_with("items", lambda i: SearchResultItem.from_dict(i)),
